#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-LU7QpzUWOWvChBXd10UmKD
key:                  wai-middleware-static-0.9.3-LU7QpzUWOWvChBXd10UmKD
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  58def6564af6974f82094c56ee87d582
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-LU7QpzUWOWvChBXd10UmKD
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-62KyUBG4ZgmGpNMNR9lueV
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-CS2R1q6F1RR95pO7btSbPN directory-1.3.8.5
    expiring-cache-map-0.0.6.1-1i0749l2jjUFxxEAG2S1Js
    filepath-1.4.300.1 http-types-0.12.4-CXiZJUbLhJFHeSLHvVo6Rt
    mime-types-0.1.2.1-1xtxegTvlKyFu1aTXaUpBN
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC text-2.0.2 time-1.12.2
    wai-3.2.4-33aeOeERzkeGIF7OkDVW43

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

